# Data Sources

Figure 10. Comparison of the thermal conductivity of porous Si
(this work) with that of bulk crystalline silicon (Glassbrenner and
Slack 1964), a-Si (Lee et al 1991), a-Si : H (Cahill et al 1989) and
different other C-MOS compatible films (mesoporous silica (Shin
et al 2008), vitreous silica (Smith et al 1978) and silicon nitride (Lee
and Cahill 1997)).
